@@ -13,7 +13,8 @@ use Module::Build::ConfigData;
 use Config;
 
 our @EXPORT = qw(run_build_pl run_build clean_install check_tree
-                 set_module_dir touch_file if_has_html if_has_man %Config);
+                 set_module_dir touch_file if_has_html if_has_man
+                 if_has_man_path %Config);
 
 my $module_dir = 'Call set_module_dir()';
 my $support_executable_bit = 0;
@@ -21,15 +22,16 @@ my $support_html =    Module::Build::ConfigData->feature( 'HTML_support' )
                    && defined $Config{installhtmldir}
                    && length $Config{installhtmldir};
 my $support_man =    Module::Build::ConfigData->feature( 'manpage_support' )
-                  && (    (    defined $Config{installman3dir}
-                            && length $Config{installman3dir} )
-                       || (    defined $Config{installsiteman3dir}
-                            && length $Config{installsiteman3dir} ) )
                   && defined $Config{man3ext}
                   && length $Config{man3ext};
+my $has_man_path =    (    defined $Config{installman3dir}
+                        && length $Config{installman3dir} )
+                   || (    defined $Config{installsiteman3dir}
+                        && length $Config{installsiteman3dir} );
 
 sub if_has_html { $support_html ? @_ : () }
 sub if_has_man  { $support_man  ? @_ : () }
+sub if_has_man_path { $support_man && $has_man_path? @_ : () }
 
 sub set_module_dir {
     $module_dir = $_[0];
